==> qt-components-1.4_1.4.9-2.tar.gz: qt-components-1.4-1.4.9/tests/auto/meego/api_window/tst_quickcomponentswindow.cpp <==
/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Components project.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtTest/QtTest>
#include <QtTest/QSignalSpy>
#include <QDeclarativeEngine>
#include <qdeclarativecontext.h>
#include <qdeclarativecomponent.h>
#include <qdeclarativeview.h>
#include <qdeclarativeitem.h>

#include "tst_quickcomponentstest.h"

class tst_quickcomponentswindow : public QObject
{
    Q_OBJECT

private slots:
    void init();
    void simpleOrientationChange();
private:
    QObject *componentObject;
};

void tst_quickcomponentswindow::init()
{
    // Initialize test
    QString errors; 
    componentObject = tst_quickcomponentstest::createComponentFromFile("tst_quickcomponentswindow.qml", &errors);
    QVERIFY2(componentObject, qPrintable(errors));             
}

void tst_quickcomponentswindow::simpleOrientationChange()
{
    QString retVal;
    QVariant retPage;

    QMetaObject::invokeMethod(componentObject, "rotateToLandscape", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 0"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Landscape"));
    
    QMetaObject::invokeMethod(componentObject, "rotateToPortrait", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 270"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Portrait"));

    QMetaObject::invokeMethod(componentObject, "rotateToLandscape", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 0"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Landscape"));
}

QTEST_MAIN(tst_quickcomponentswindow)

#include "tst_quickcomponentswindow.moc"

==> qt-components-10_1.0-pre1.orig.tar.gz: qt-components-10-1.0-pre1/tests/auto/meego/api_window/tst_quickcomponentswindow.cpp <==
/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Components project.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtTest/QtTest>
#include <QtTest/QSignalSpy>
#include <QDeclarativeEngine>
#include <QtDeclarative/qdeclarativecontext.h>
#include <QtDeclarative/qdeclarativecomponent.h>
#include <QtDeclarative/qdeclarativeview.h>
#include <QtDeclarative/qdeclarativeitem.h>

#include "tst_quickcomponentstest.h"

class tst_quickcomponentswindow : public QObject
{
    Q_OBJECT

private slots:
    void init();
    void simpleOrientationChange();
private:
    QObject *componentObject;
};

void tst_quickcomponentswindow::init()
{
    // Initialize test
    QString errors; 
    componentObject = tst_quickcomponentstest::createComponentFromFile("tst_quickcomponentswindow.qml", &errors);
    QVERIFY2(componentObject, qPrintable(errors));             
}

void tst_quickcomponentswindow::simpleOrientationChange()
{
    QString retVal;
    QVariant retPage;

    QMetaObject::invokeMethod(componentObject, "rotateToLandscape", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 0"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Landscape"));
    
    QMetaObject::invokeMethod(componentObject, "rotateToPortrait", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 270"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Portrait"));

    QMetaObject::invokeMethod(componentObject, "rotateToLandscape", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QMetaObject::invokeMethod(componentObject, "getOrientation", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Angle 0"));

    QMetaObject::invokeMethod(componentObject, "getOrientationLabelText", Qt::DirectConnection, Q_RETURN_ARG(QVariant, retPage));
    QCOMPARE(retPage.toString(), QString("Landscape"));
}

QTEST_MAIN(tst_quickcomponentswindow)

#include "tst_quickcomponentswindow.moc"
